@@ -1,17 +1,16 @@
 import requests
 import urllib
-import urllib2
 import json
 
 class HttpLib:
 
-    def get(self, endpoint, args = {}):
-        url = endpoint + "?" + urllib.urlencode(args)
-        resp = urllib2.urlopen(url)
-        if resp.getcode() == 200:
-            return json.loads(resp.read())
-        return None
-
+    def get(self, endpoint, args = None):
+        url = endpoint
+        if args: 
+            url = endpoint + "?" + urllib.urlencode(args)
+        r = requests.get(url)
+        return r.json()
+        
     def post(self, endpoint, args, data):
         url = endpoint + "?" + urllib.urlencode(args)
         headers = {'Content-type': 'application/json'}
